@@ -13,8 +13,8 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 3581 $
-#:#  Last changed: $Date: 2020-09-03 08:58:34 +0200 (Do, 03 Sep 2020) $
+#:#  File version: $Revision: 4166 $
+#:#  Last changed: $Date: 2021-01-05 13:42:19 +0100 (Tue, 05 Jan 2021) $
 #:#  Last changed by: $Author: pahlke $
 #:# 
 
@@ -250,13 +250,13 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 #' @description 
 #' Returns an \code{AccrualTime} object that contains the accrual time and the accrual intensity.
 #' 
-#' @param accrualTime The assumed accrual time for the study, default is \code{c(0,12)} (see details).
-#' @param accrualIntensity A value or vector of accrual intensities, default is the relative 
-#'        intensity \code{0.1} (see details).
+#' @inheritParams param_accrualTime
+#' @inheritParams param_accrualIntensity
+#' @inheritParams param_accrualIntensityType
 #' @param maxNumberOfSubjects The maximum number of subjects.
 #' @inheritParams param_three_dots
 #' 
-#' @template details_piecewise_accrual 
+#' @template details_piecewise_accrual
 #' 
 #' @seealso \code{\link{getNumberOfSubjects}} for calculating the number of subjects at given time points. 
 #' 
@@ -278,7 +278,8 @@ getPiecewiseSurvivalTime <- function(piecewiseSurvivalTime = NA_real_,
 #' 
 getAccrualTime <- function(accrualTime = NA_real_, 
 		...,
-		accrualIntensity = NA_real_, 
+		accrualIntensity = NA_real_,
+		accrualIntensityType = c("auto", "absolute", "relative"), 
 		maxNumberOfSubjects = NA_real_) {
 	
 	.warnInCaseOfUnknownArguments(functionName = "getAccrualTime", ..., 
@@ -300,8 +301,18 @@ getAccrualTime <- function(accrualTime = NA_real_,
 		return(accrualTime$.accrualTime)
 	}
 	
+	accrualIntensityType <- match.arg(accrualIntensityType)
+	
 	.assertIsNumericVector(accrualIntensity, "accrualIntensity", naAllowed = TRUE)
 	.assertIsValidMaxNumberOfSubjects(maxNumberOfSubjects, naAllowed = TRUE)
+	.assertIsSingleCharacter(accrualIntensityType, "accrualIntensityType")
+	absoluteAccrualIntensityEnabled <- NA
+	if (accrualIntensityType == "absolute") {
+		absoluteAccrualIntensityEnabled <- TRUE
+	}
+	else if (accrualIntensityType == "relative") {
+		absoluteAccrualIntensityEnabled <- FALSE
+	}
 	
 	args <- list(...)
 	showWarnings <- args[["showWarnings"]]
@@ -312,7 +323,8 @@ getAccrualTime <- function(accrualTime = NA_real_,
 	return(AccrualTime(accrualTime = accrualTime, 
 		accrualIntensity = accrualIntensity, 
 		maxNumberOfSubjects = maxNumberOfSubjects, 
-		showWarnings = showWarnings))
+		showWarnings = showWarnings,
+		absoluteAccrualIntensityEnabled = absoluteAccrualIntensityEnabled))
 }
 
 #' 
@@ -1236,23 +1248,25 @@ AccrualTime <- setRefClass("AccrualTime",
 				accrualIntensity = NA_real_, 
 				maxNumberOfSubjects = NA_real_,
 				showWarnings = TRUE, 
-				silent = FALSE) {
+				absoluteAccrualIntensityEnabled = NA) {
 				
 			callSuper(accrualTime = NA_real_,
 				accrualIntensity = accrualIntensity,
 				maxNumberOfSubjects = maxNumberOfSubjects, 
-				.showWarnings = showWarnings, ...)
+				.showWarnings = showWarnings,
+				absoluteAccrualIntensityEnabled = absoluteAccrualIntensityEnabled, ...)
 			
 			endOfAccrualIsUserDefined <<- NA
 			followUpTimeMustBeUserDefined <<- NA
 			maxNumberOfSubjectsIsUserDefined <<- NA
 			maxNumberOfSubjectsCanBeCalculatedDirectly <<- TRUE
-			absoluteAccrualIntensityEnabled <<- NA
+			#absoluteAccrualIntensityEnabled <<- NA
 			.setParameterType("endOfAccrualIsUserDefined", C_PARAM_GENERATED)
 			.setParameterType("followUpTimeMustBeUserDefined", C_PARAM_GENERATED)
 			.setParameterType("maxNumberOfSubjectsIsUserDefined", C_PARAM_GENERATED)
 			.setParameterType("maxNumberOfSubjectsCanBeCalculatedDirectly", C_PARAM_GENERATED)
-			.setParameterType("absoluteAccrualIntensityEnabled", C_PARAM_GENERATED)
+			.setParameterType("absoluteAccrualIntensityEnabled", 
+				ifelse(is.na(absoluteAccrualIntensityEnabled), C_PARAM_GENERATED, C_PARAM_USER_DEFINED))
 			
 			accrualIntensityRelative <<- NA_real_
 			.setParameterType("accrualIntensityRelative", C_PARAM_NOT_APPLICABLE)
@@ -1262,7 +1276,7 @@ AccrualTime <- setRefClass("AccrualTime",
 			
 			# case 6 correction
 			if (!endOfAccrualIsUserDefined && maxNumberOfSubjectsIsUserDefined && 
-					!absoluteAccrualIntensityEnabled) {
+					!.self$absoluteAccrualIntensityEnabled) {
 				remainingTime <<- NA_real_ 
 				.setParameterType("remainingTime", C_PARAM_NOT_APPLICABLE)
 				.self$accrualTime <<- .self$accrualTime[1:length(.self$accrualIntensity)]
@@ -1390,7 +1404,7 @@ AccrualTime <- setRefClass("AccrualTime",
 				}
 			}
 			if (!isTRUE(all.equal(numberOfSubjects, maxNumberOfSubjects, tolerance = 1e-03)) && 
-					.isAbsoluteAccrualIntensity(accrualIntensity)) {
+					absoluteAccrualIntensityEnabled) {
 				stop(C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS, 
 					"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") disagrees with ",
 					"the defined accrual time and intensity: ",
@@ -1703,6 +1717,7 @@ AccrualTime <- setRefClass("AccrualTime",
 		},
 		
 		.initAccrualIntensityAbsolute = function() {
+			
 			if (is.null(maxNumberOfSubjects) || length(maxNumberOfSubjects) != 1 || 
 					is.na(maxNumberOfSubjects) || maxNumberOfSubjects == 0) {
 				return(invisible())
@@ -1724,7 +1739,7 @@ AccrualTime <- setRefClass("AccrualTime",
 					
 					.validateAccrualTimeAndIntensity()
 
-					if (.isAbsoluteAccrualIntensity(accrualIntensity) && 
+					if (absoluteAccrualIntensityEnabled && 
 							.getParameterType("maxNumberOfSubjects") == C_PARAM_USER_DEFINED) {
 						
 						if (.getParameterType("accrualTime") == C_PARAM_DEFAULT_VALUE) {
@@ -1739,7 +1754,7 @@ AccrualTime <- setRefClass("AccrualTime",
 								.getFormula(), " = ", .getSampleSize())
 						}
 					} else {
-						if (.isRelativeAccrualIntensity(accrualIntensity) && 
+						if (!absoluteAccrualIntensityEnabled && # .isRelativeAccrualIntensity(accrualIntensity)
 								.getParameterType("accrualIntensity") == C_PARAM_USER_DEFINED &&
 								.getParameterType("accrualTime") == C_PARAM_DEFAULT_VALUE &&
 								.getParameterType("maxNumberOfSubjects") == C_PARAM_USER_DEFINED) {
@@ -1855,7 +1870,9 @@ AccrualTime <- setRefClass("AccrualTime",
 				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT, "'accrualTime' must be a list or a numeric vector")
 			}
 			
-			absoluteAccrualIntensityEnabled <<- .isAbsoluteAccrualIntensity(accrualIntensity)
+			if (is.na(absoluteAccrualIntensityEnabled)) {
+				absoluteAccrualIntensityEnabled <<- .isAbsoluteAccrualIntensity(accrualIntensity)
+			}
 			if (is.null(maxNumberOfSubjects) || length(maxNumberOfSubjects) == 0 ||
 					any(is.na(maxNumberOfSubjects))) {
 				if (length(accrualTime) != length(accrualIntensity) + 1 || 
@@ -1906,7 +1923,7 @@ AccrualTime <- setRefClass("AccrualTime",
 							.calculateRemainingTime()
 						} else {
 							if (length(accrualTime) == length(accrualIntensity) + 1 && 
-									.isAbsoluteAccrualIntensity(accrualIntensity)) {
+									absoluteAccrualIntensityEnabled) {
 								stop(C_EXCEPTION_TYPE_CONFLICTING_ARGUMENTS, 
 									"'maxNumberOfSubjects' (", maxNumberOfSubjects, ") disagrees with ",
 									"the defined accrual time and intensity: ",
@@ -1918,7 +1935,7 @@ AccrualTime <- setRefClass("AccrualTime",
 						}
 					} else {
 						if ((length(maxNumberOfSubjects) != 1 || is.na(maxNumberOfSubjects)) &&
-								.isAbsoluteAccrualIntensity(accrualIntensity)) {
+								absoluteAccrualIntensityEnabled) {
 							maxNumberOfSubjects <<- sampleSize
 							.setParameterType("maxNumberOfSubjects", C_PARAM_GENERATED)
 						}
@@ -2068,13 +2085,6 @@ AccrualTime <- setRefClass("AccrualTime",
 				warning("It makes no sense to start 'accrualIntensity' (", 
 					.arrayToString(accrualIntensity), ") with 0")
 			}
-			
-			if (sum(.isAbsoluteAccrualIntensity(accrualIntensity)) > 0 && 
-					sum(.isRelativeAccrualIntensity(accrualIntensity)) > 0) {
-				stop(C_EXCEPTION_TYPE_ILLEGAL_ARGUMENT,
-					"the values of 'accrualIntensity' (", .arrayToString(accrualIntensity), ") ", 
-					"must exclusive absolute or relative, i.e., all (= 0 || >= 1) or all (< 1)")
-			}
 		},
 		
 		.validateInitialization = function() {
