@@ -13,9 +13,9 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 3519 $
-#:#  Last changed: $Date: 2020-08-21 14:17:44 +0200 (Fr, 21 Aug 2020) $
-#:#  Last changed by: $Author: pahlke $
+#:#  File version: $Revision: 3814 $
+#:#  Last changed: $Date: 2020-10-30 17:12:19 +0100 (Fri, 30 Oct 2020) $
+#:#  Last changed by: $Author: wassmer $
 #:# 
 
 # @title
@@ -619,7 +619,7 @@
 		
 	if (!normalApproximation && dataInput$getNumberOfGroups() == 2) {
 		normalApproximation <- TRUE
-		message("Repeated confidence intervals is calculated under the normal approximation")
+		message("Repeated confidence intervals will be calculated under the normal approximation")
 	}	
 	
 	futilityCorr <- rep(NA_real_, design$kMax) # necessary for adjustment for binding futility boundaries
