@@ -13,9 +13,9 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 3793 $
-#:#  Last changed: $Date: 2020-10-27 12:14:37 +0100 (Tue, 27 Oct 2020) $
-#:#  Last changed by: $Author: pahlke $
+#:#  File version: $Revision: 4391 $
+#:#  Last changed: $Date: 2021-02-12 15:23:10 +0100 (Fr, 12 Feb 2021) $
+#:#  Last changed by: $Author: wassmer $
 #:# 
 
 C_LOG_LEVEL_TRACE <- "TRACE"
@@ -48,7 +48,7 @@ C_ALPHA_DEFAULT <- 0.025
 C_BETA_DEFAULT <- 0.2
 C_SIDED_DEFAULT <- 1L
 C_KMAX_DEFAULT <- 3L 
-C_KMAX_UPPER_BOUND <- 10L
+C_KMAX_UPPER_BOUND <- 20L
 C_KMAX_UPPER_BOUND_FISHER <- 6L
 
 C_NA_MAX_DEFAULT <- 100L
@@ -104,19 +104,19 @@ C_DIRECTION_LOWER = "lower"
 C_DIRECTION_UPPER = "upper"
 
 # 
-# Constants used in 'f_analysis_multiarm'
+# Constants used in 'f_analysis_multiarm' 
 # 
-C_INTERSECTION_TEST_DUNNETT <- "Dunnett"
 C_INTERSECTION_TEST_MULTIARMED_DEFAULT <- "Dunnett"
-C_VARIANCE_OPTION_DUNNETT <- "overallPooled" 
-C_VARIANCE_OPTION_DEFAULT <- "overallPooled" 
-C_VARIANCE_OPTIONS <- c("overallPooled", "pairwisePooled", "notPooled") 
-C_INTERSECTION_TESTS <- c(
+C_INTERSECTION_TESTS_MULTIARMED <- c(
 	"Bonferroni",
 	"Simes",
 	"Sidak",
 	"Dunnett",
 	"Hierarchical")
+C_VARIANCE_OPTION_DUNNETT <- "overallPooled" 
+C_VARIANCE_OPTION_MULTIARMED_DEFAULT <- "overallPooled" 
+C_VARIANCE_OPTIONS_MULTIARMED <- c("overallPooled", "pairwisePooled", "notPooled") 
+C_STRATIFIED_ANALYSIS_DEFAULT <- TRUE
 
 # 
 # Constants used in 'parameters.R'
@@ -158,7 +158,7 @@ C_TYPE_OF_SHAPE_DEFAULT <- C_TYPES_OF_SHAPE[1]
 
 C_SUCCESS_CRITERIONS <- c("all", "atLeastOne")
 C_SUCCESS_CRITERION_DEFAULT <- C_SUCCESS_CRITERIONS[1]
-C_EFFECT_MEASURES <- c("effectDifference", "testStatistic")
+C_EFFECT_MEASURES <- c("effectEstimate", "testStatistic")
 C_EFFECT_MEASURE_DEFAULT <- C_EFFECT_MEASURES[1]
 
 # 
@@ -189,6 +189,7 @@ C_STDEV_DEFAULT <- 1
 C_TYPE_OF_DESIGN_OF <- "OF" # O'Brien & Fleming
 C_TYPE_OF_DESIGN_P <- "P"   # Pocock, 
 C_TYPE_OF_DESIGN_WT <- "WT" # Wang & Tsiatis Delta class
+C_TYPE_OF_DESIGN_PT <- "PT" # Pampallona & Tsiatis class
 C_TYPE_OF_DESIGN_HP <- "HP" # Haybittle & Peto
 C_TYPE_OF_DESIGN_WT_OPTIMUM <- "WToptimum" # Optimum design within Wang & Tsiatis class
 C_TYPE_OF_DESIGN_AS_P <- "asP"      # Pocock type alpha spending
@@ -198,6 +199,19 @@ C_TYPE_OF_DESIGN_AS_HSD <- "asHSD"  # Hwang, Shi & DeCani alpha spending
 C_TYPE_OF_DESIGN_AS_USER <- "asUser" # user defined alpha spending
 C_DEFAULT_TYPE_OF_DESIGN <- C_TYPE_OF_DESIGN_OF # the default type of design
 
+C_TYPE_OF_DESIGN_LIST <- list(
+	"OF" = "O'Brien & Fleming", 
+	"P" = "Pocock", 
+	"WT" = "Wang & Tsiatis Delta class", 
+	"PT" = "Pampallona & Tsiatis class",
+	"HP" = "Haybittle & Peto", 
+	"WToptimum" = "Optimum design within Wang & Tsiatis class", 
+	"asP" = "Pocock type alpha spending", 
+	"asOF" = "O'Brien & Fleming type alpha spending", 
+	"asKD" = "Kim & DeMets alpha spending", 
+	"asHSD" = "Hwang, Shi & DeCani alpha spending", 
+	"asUser" = "user defined alpha spending")
+
 C_PLOT_SHOW_SOURCE_ARGUMENTS <- c("commands", "axes", "test", "validate")
 
 C_PLOT_MAIN_CONDITIONAL_POWER_WITH_LIKELIHOOD <- "Conditional Power with Likelihood"
@@ -208,6 +222,7 @@ C_PLOT_YLAB_CONDITIONAL_POWER_WITH_LIKELIHOOD <- "Conditional power / Likelihood
 		C_TYPE_OF_DESIGN_OF,
 		C_TYPE_OF_DESIGN_P,
 		C_TYPE_OF_DESIGN_WT,
+		C_TYPE_OF_DESIGN_PT,
 		C_TYPE_OF_DESIGN_HP,
 		C_TYPE_OF_DESIGN_WT_OPTIMUM,
 		C_TYPE_OF_DESIGN_AS_P,
@@ -247,6 +262,15 @@ C_TYPE_OF_DESIGN_BS_KD <- "bsKD"     # Kim & DeMets beta spending
 C_TYPE_OF_DESIGN_BS_HSD <- "bsHSD"   # Hwang, Shi & DeCani beta spending
 C_TYPE_OF_DESIGN_BS_USER <- "bsUser" # user defined beta spending
 
+C_TYPE_OF_DESIGN_BS_LIST <- list(
+	"none" = "none",
+	"bsP" = "Pocock type beta spending", 
+	"bsOF" = "O'Brien & Fleming type beta spending", 
+	"bsKD" = "Kim & DeMets beta spending", 
+	"bsHSD" = "Hwang, Shi & DeCani beta spending", 
+	"bsUser" = "user defined beta spending"
+)
+
 .getBetaSpendingDesignTypes <- function() {
 	return(c(
 		C_TYPE_OF_DESIGN_BS_NONE,
@@ -372,6 +396,8 @@ C_PARAMETER_NAMES <- list(
 	futilityBoundsNonBinding = "Futility bounds (non-binding)",
 	typeOfDesign = "Type of design",
 	deltaWT = "Delta for Wang & Tsiatis Delta class",
+	deltaPT0 = "Delta0 for Pampallona & Tsiatis class", 
+	deltaPT1 = "Delta1 for Pampallona & Tsiatis class", 
 	optimizationCriterion = "Optimization criterion for optimum design within Wang & Tsiatis class",
 	gammaA = "Parameter for alpha spending function",
 	gammaB = "Parameter for beta spending function",
@@ -406,8 +432,9 @@ C_PARAMETER_NAMES <- list(
 	pi2H1 = "pi(2) under H1",
 	nPlanned = "Planned sample size",
 	
-	piControl = "Control rate",
-	piTreatments = "Treatment rate",
+	piControl = "Assumed control rate",
+	piControls = "Assumed control rate",
+	piTreatments = "Assumed treatment rate",
 	effectSizes = "Overall effect sizes",
 	testStatistics = "Test statistics",
 	pValues = "p-values",
@@ -503,8 +530,8 @@ C_PARAMETER_NAMES <- list(
 	
 	twoSidedPower = "Two-sided power",
 	
-	plannedEvents = "Planned events",
-	plannedSubjects = "Planned subjects",
+	plannedEvents = "Planned cumulative overall events",
+	plannedSubjects = "Planned cumulative subjects", # per arm (multi-arm); overall (base)
 	minNumberOfEventsPerStage = "Minimum number of events per stage",
 	maxNumberOfEventsPerStage = "Maximum number of events per stage",
 	minNumberOfSubjectsPerStage = "Minimum number of subjects per stage",
@@ -532,12 +559,14 @@ C_PARAMETER_NAMES <- list(
 	effect = "Effect",
 	maxNumberOfEvents = "Maximum number of events",
 	
-	criticalValuesEffectScale = "Critical values (effect scale)",
-	criticalValuesEffectScaleLower = "Lower critical values (effect scale)",
-	criticalValuesEffectScaleUpper = "Upper critical values (effect scale)",
+	criticalValuesEffectScale = "Critical values (treatment effect scale)",
+	criticalValuesEffectScaleLower = "Lower critical values (treatment effect scale)",
+	criticalValuesEffectScaleUpper = "Upper critical values (treatment effect scale)",
 	criticalValuesPValueScale = "Local one-sided significance levels",
 	".design$stageLevels" = "Local one-sided significance levels",
-	futilityBoundsEffectScale = "Futility bounds (effect scale)",
+	futilityBoundsEffectScale = "Futility bounds (treatment effect scale)",
+	futilityBoundsEffectScaleLower = "Lower futility bounds (treatment effect scale)",
+	futilityBoundsEffectScaleUpper = "Upper futility bounds (treatment effect scale)",
 	futilityBoundsPValueScale = "Futility bounds (1-sided p-value scale)",
 	
 	analysisTime = "Analysis time",
@@ -557,6 +586,7 @@ C_PARAMETER_NAMES <- list(
 	eventsPerStage = "Cumulative number of events",
 	expectedNumberOfEvents = "Observed number of events",
 	expectedNumberOfSubjects = "Observed number of subjects",
+	singleNumberOfEventsPerStage = "Single number of events",
 	
 	endOfAccrualIsUserDefined = "End of accrual is user defined",
 	followUpTimeMustBeUserDefined = "Follow-up time must be user defined",
@@ -619,7 +649,9 @@ C_PARAMETER_NAMES <- list(
 	calcSubjectsFunction = "Calculate subjects function",
 	calcEventsFunction = "Calculate events function",
 	selectArmsFunction = "Select arms function",
-	numberOfActiveArms = "Number of active arms"
+	numberOfActiveArms = "Number of active arms",
+	
+	correlationComputation = "Correlation computation method"
 )
 
 .getParameterNames <- function(design = NULL, designPlan = NULL) {
@@ -698,6 +730,8 @@ C_TABLE_COLUMN_NAMES <- list(
 	futilityBoundsNonBinding = "Futility bound (non-binding)",
 	typeOfDesign = "Type of design",
 	deltaWT = "Delta (Wang & Tsiatis)",
+	deltaPT0 = "Delta0 (Pampallona & Tsiatis)", 
+	deltaPT1 = "Delta1 (Pampallona & Tsiatis)", 
 	optimizationCriterion = "Optimization criterion (Wang & Tsiatis)",
 	gammaA = "Parameter for alpha spending function",
 	gammaB = "Parameter for beta spending function",
@@ -733,8 +767,9 @@ C_TABLE_COLUMN_NAMES <- list(
 	pi2H1 = "pi(2) under H1",
 	nPlanned = "Planned sample size",
 	
-	piControl = "Control rate",
-	piTreatments = "Treatment rate",
+	piControl = "Assumed control rate",
+	piControls = "Assumed control rate",
+	piTreatments = "Assumed treatment rate",
 	stages = "Stage",
 	effectSizes = "Overall effect size",
 	testStatistics = "Test statistic",
@@ -832,8 +867,8 @@ C_TABLE_COLUMN_NAMES <- list(
 	
 	twoSidedPower = "Two-sided power",
 	
-	plannedEvents = "Required planned events",
-	plannedSubjects = "Required planned subjects",
+	plannedEvents = "Planned cumulative events",
+	plannedSubjects = "Planned cumulative subjects",
 	minNumberOfEventsPerStage = "Minimum # events per stage",
 	maxNumberOfEventsPerStage = "Maximum # events per stage",
 	minNumberOfSubjectsPerStage = "Minimum # of subjects per stage",
@@ -860,12 +895,14 @@ C_TABLE_COLUMN_NAMES <- list(
 	effect = "Effect",
 	maxNumberOfEvents = "Maximum # events",
 	
-	criticalValuesEffectScale = "Critical value (effect scale)",
-	criticalValuesEffectScaleLower = "Lower critical value (effect scale)",
-	criticalValuesEffectScaleUpper = "Upper critical value (effect scale)",
+	criticalValuesEffectScale = "Critical value (treatment effect scale)",
+	criticalValuesEffectScaleLower = "Lower critical value (treatment effect scale)",
+	criticalValuesEffectScaleUpper = "Upper critical value (treatment effect scale)",
 	criticalValuesPValueScale = "Local one-sided significance level",
 	".design$stageLevels" = "Local one-sided significance level",
-	futilityBoundsEffectScale = "Futility bound (effect scale)",
+	futilityBoundsEffectScale = "Futility bound (treatment effect scale)",
+	futilityBoundsEffectScaleLower = "Lower futility bound (treatment effect scale)",
+	futilityBoundsEffectScaleUpper = "Upper futility bound (treatment effect scale)",
 	futilityBoundsPValueScale = "Futility bound (1-sided p-value scale)",
 	
 	delayedResponseAllowed = "Delayed response allowed",
@@ -878,6 +915,7 @@ C_TABLE_COLUMN_NAMES <- list(
 	eventsPerStage = "Cumulative # events", 
 	expectedNumberOfEvents = "Observed # events",
 	expectedNumberOfSubjects = "Observed # subjects",
+	singleNumberOfEventsPerStage = "Single # events",
 	
 	endOfAccrualIsUserDefined = "End of accrual is user defined",
 	followUpTimeMustBeUserDefined = "Follow-up time must be user defined",
@@ -939,7 +977,9 @@ C_TABLE_COLUMN_NAMES <- list(
 	calcSubjectsFunction = "Calc subjects fun",
 	calcEventsFunction = "Calc events fun",
 	selectArmsFunction = "Select arms fun",
-	numberOfActiveArms = "Number of active arms"
+	numberOfActiveArms = "Number of active arms",
+	
+	correlationComputation = "Correlation computation"
 )
 
 .getTableColumnNames <- function(design = NULL, designPlan = NULL) {
@@ -1121,6 +1161,8 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
 	criticalValuesEffectScaleUpper = ".formatCriticalValues",
 	criticalValuesPValueScale = ".formatProbabilities",
 	futilityBoundsEffectScale = ".formatCriticalValues",
+	futilityBoundsEffectScaleLower = ".formatCriticalValues",
+	futilityBoundsEffectScaleUpper = ".formatCriticalValues",
 	futilityBoundsPValueScale = ".formatProbabilities",
 	
 	median1 = ".formatRatesDynamic",
@@ -1132,6 +1174,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
 	eventsPerStage = ".formatEvents", 
 	expectedNumberOfEvents = ".formatEvents",
 	expectedNumberOfSubjects = ".formatEvents",
+	singleNumberOfEventsPerStage = ".formatEvents",
 	
 	time = ".formatTime",
 	overallEventProbabilities = ".formatProbabilities",
@@ -1147,6 +1190,7 @@ C_PARAMETER_FORMAT_FUNCTIONS <- list(
 	userBetaSpending = ".formatHowItIs",
 	
 	piControl = ".formatRates",
+	piControls = ".formatRates",
 	piTreatments = ".formatRates",
 	
 	adjustedStageWisePValues = ".formatPValues",
