@@ -13,8 +13,8 @@
 #:# 
 #:#  Contact us for information about our services: info@rpact.com
 #:# 
-#:#  File version: $Revision: 3688 $
-#:#  Last changed: $Date: 2020-09-24 14:37:04 +0200 (Thu, 24 Sep 2020) $
+#:#  File version: $Revision: 4311 $
+#:#  Last changed: $Date: 2021-02-03 11:38:47 +0100 (Mi, 03 Feb 2021) $
 #:#  Last changed by: $Author: pahlke $
 #:# 
 
@@ -81,22 +81,24 @@ NULL
 	return(c("alpha", "beta", "sided", "twoSidedPower"))
 }
 
-.getValidatedFutilityBounds <- function(design, kMaxLowerBound = 1, writeToDesign = TRUE) {
+.getValidatedFutilityBounds <- function(design, kMaxLowerBound = 1, 
+		writeToDesign = TRUE, twoSidedWarningForDefaultValues = TRUE) {
 	.assertIsTrialDesignInverseNormalOrGroupSequential(design)
 	return(.getValidatedFutilityBoundsOrAlpha0Vec(design = design, parameterName = "futilityBounds", 
 		defaultValue = C_FUTILITY_BOUNDS_DEFAULT, kMaxLowerBound = kMaxLowerBound,
-		writeToDesign = writeToDesign))
+		writeToDesign = writeToDesign, twoSidedWarningForDefaultValues = twoSidedWarningForDefaultValues))
 }
 
-.getValidatedAlpha0Vec <- function(design, kMaxLowerBound = 1, writeToDesign = TRUE) {
+.getValidatedAlpha0Vec <- function(design, kMaxLowerBound = 1, 
+		writeToDesign = TRUE, twoSidedWarningForDefaultValues = TRUE) {
 	.assertIsTrialDesignFisher(design)
 	return(.getValidatedFutilityBoundsOrAlpha0Vec(design = design, parameterName = "alpha0Vec", 
 		defaultValue = C_ALPHA_0_VEC_DEFAULT, kMaxLowerBound = kMaxLowerBound,
-		writeToDesign = writeToDesign))
+		writeToDesign = writeToDesign, twoSidedWarningForDefaultValues = twoSidedWarningForDefaultValues))
 }
 
 .getValidatedFutilityBoundsOrAlpha0Vec <- function(design, parameterName, defaultValue, 
-	kMaxLowerBound, writeToDesign) {
+		kMaxLowerBound, writeToDesign, twoSidedWarningForDefaultValues = TRUE) {
 	
 	parameterValues <- design[[parameterName]]
 	
@@ -111,9 +113,13 @@ NULL
 		}
 	}
 	
-	if (design$sided == 2 && .isDefinedArgument(parameterValues) && any(na.omit(parameterValues) != defaultValue)) {
+	if (design$sided == 2 && .isDefinedArgument(parameterValues) && !(design$typeOfDesign == "PT") &&
+			(twoSidedWarningForDefaultValues && !all(is.na(parameterValues)) || 
+			(!twoSidedWarningForDefaultValues && any(na.omit(parameterValues) != defaultValue)))) {
+		
 		warning("'", parameterName, "' (", .arrayToString(parameterValues), 
 			") will be ignored because the design is two-sided", call. = FALSE)
+		parameterValues <- rep(defaultValue, design$kMax - 1)
 	}
 	
 	if (writeToDesign) {
@@ -150,9 +156,9 @@ NULL
 			if (.isDefaultVector(parameterValues, rep(defaultValue, design$kMax - 1))) {
 				.setParameterType(design, parameterName, C_PARAM_DEFAULT_VALUE)
 			}
-		}
+		}		
 		
-		if (.isBetaSpendingDesignWithDefinedFutilityBounds(design, parameterName, writeToDesign)) {
+		if (.isBetaSpendingOrPampallonaTsiatisDesignWithDefinedFutilityBounds(design, parameterName, writeToDesign)) {
 			return(rep(defaultValue, design$kMax - 1))
 		}
 		
@@ -174,15 +180,20 @@ NULL
 			kMaxLowerBound = kMaxLowerBound, kMaxUpperBound = kMaxUpperBound)
 	}
 	
-	if (.isBetaSpendingDesignWithDefinedFutilityBounds(design, parameterName, writeToDesign)) {
+	if (.isBetaSpendingOrPampallonaTsiatisDesignWithDefinedFutilityBounds(design, parameterName, writeToDesign)) {
 		return(rep(defaultValue, design$kMax - 1))
 	}
 	
 	return(parameterValues)
 }
 
-.isBetaSpendingDesignWithDefinedFutilityBounds <- function(design, parameterName, writeToDesign) {
-	if (.isTrialDesignFisher(design) || !.isBetaSpendingDesignType(design$typeBetaSpending)) {
+# Check whether design is a beta spending or Pampallona Tsiatis design
+.isBetaSpendingOrPampallonaTsiatisDesignWithDefinedFutilityBounds <- function(design, parameterName, writeToDesign) {
+	if (.isTrialDesignFisher(design)) {
+		return(FALSE)
+	}
+	
+	if (!.isBetaSpendingDesignType(design$typeBetaSpending) && design$typeOfDesign != "PT") {
 		return(FALSE)
 	}
 	
@@ -589,15 +600,16 @@ NULL
 #' starting times (\code{piecewiseSurvivalTime}) and a vector of hazard rates (\code{piecewiseLambda}).
 #' You can also use a list that defines the starting times and piecewise 
 #' lambdas together and define piecewiseSurvivalTime as this list.
-#' The list needs to have the form, e.g., #' piecewiseSurvivalTime <- list(
+#' The list needs to have the form, e.g., 
+#' piecewiseSurvivalTime <- list(
 #'     "0 - <6"   = 0.025, 
 #'     "6 - <9"   = 0.04, 
 #'     "9 - <15"  = 0.015, 
-#'     ">=15"      = 0.007) 
+#'     ">=15"      = 0.007) .
 #' For the Weibull case, you can also specify a shape parameter kappa in order to 
-#' calculated probabilities, quantiles, or random numbers.
-#' In this case, no piecewise definition is possible, i.e., only piecewiseLambda and 
-#' kappa need to be specified. 
+#' calculate probabilities, quantiles, or random numbers.
+#' In this case, no piecewise definition is possible, i.e., only piecewiseLambda
+#' (as a single value) and kappa need to be specified. 
 #' 
 #' @return Returns a \code{\link[base]{numeric}} value or vector will be returned.
 #' 
@@ -830,6 +842,7 @@ getMedianByPi <- function(piValue,
 	return(eventsOverStages)
 }
 
+# example: .convertStageWiseToOverallValues(array(1:4, c(3, 4)))
 .convertStageWiseToOverallValues <- function(valuesPerStage) {
 	if (is.array(valuesPerStage) && length(dim(valuesPerStage)) == 3) {
 		eventsOverStages <- array(dim = dim(valuesPerStage))
@@ -843,4 +856,43 @@ getMedianByPi <- function(piValue,
 	return(.convertStageWiseToOverallValuesInner(valuesPerStage))
 }
 
-
+.getDesignParametersToShow <- function(paramaterSet) {
+	if (is.null(paramaterSet[[".design"]])) {
+		stop(C_EXCEPTION_TYPE_RUNTIME_ISSUE, 
+			"'paramaterSet' (", class(paramaterSet), ") does not contain '.design' field")
+	}
+	
+	designParametersToShow <- c(".design$stages")
+	if (grepl("Dunnett", class(paramaterSet))) {
+		designParametersToShow <- c(
+			designParametersToShow,
+			".design$alpha",
+			".design$informationAtInterim",
+			".design$secondStageConditioning",
+			".design$sided")
+	} else {
+		design <- paramaterSet$.design
+		designParametersToShow <- c()
+		if (design$kMax > 1) {
+			designParametersToShow <- c(designParametersToShow, ".design$informationRates")
+		}
+		designParametersToShow <- c(designParametersToShow, ".design$criticalValues")
+		if (design$kMax > 1) {
+			if (.isTrialDesignFisher(design)) {
+				designParametersToShow <- c(designParametersToShow, ".design$alpha0Vec")
+			} else {
+				designParametersToShow <- c(designParametersToShow, ".design$futilityBounds")
+			}
+			designParametersToShow <- c(designParametersToShow, ".design$alphaSpent")
+			designParametersToShow <- c(designParametersToShow, ".design$stageLevels")
+		} else {
+			if (design$sided == 2) {
+				designParametersToShow <- c(designParametersToShow, ".design$twoSidedPower")
+			}
+		}
+		designParametersToShow <- c(designParametersToShow, ".design$alpha")
+		designParametersToShow <- c(designParametersToShow, ".design$beta")
+		designParametersToShow <- c(designParametersToShow, ".design$sided")
+	}
+	return(designParametersToShow)
+}
