@@ -2,157 +2,28 @@
  *
  * -- Simulation of survival data with group sequential and combination test --
  *
- * This file is part of the R package RPACT - R Package for Adaptive Clinical Trials.
+ * This file is part of the R package rpact:
+ * Confirmatory Adaptive Clinical Trial Design and Analysis
  *
- * File version: 1.0.1
- * Date: 09-05-2019
  * Author: Gernot Wassmer, PhD, and Friedrich Pahlke, PhD
  * Licensed under "GNU Lesser General Public License" version 3
  * License text can be found here: https://www.r-project.org/Licenses/LGPL-3
  *
  * RPACT company website: https://www.rpact.com
- * RPACT package website: https://www.rpact.org
+ * rpact package website: https://www.rpact.org
  *
  * Contact us for information about our services: info@rpact.com
  *
+ * File version: $Revision: 4248 $
+ * Last changed: $Date: 2021-01-22 15:57:53 +0100 (Fri, 22 Jan 2021) $
+ * Last changed by: $Author: pahlke $
+ *
  */
 
 #include <Rcpp.h>
+#include "f_utilities.h"
 using namespace Rcpp;
 
-NumericVector vectorSum(NumericVector x, NumericVector y) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = x[i] + y[i];
-	}
-	return result;
-}
-
-NumericVector vectorSqrt(NumericVector x) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = sqrt(x[i]);
-	}
-	return result;
-}
-
-NumericVector vectorDivide(NumericVector x, double value) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = x[i] / value;
-	}
-	return result;
-}
-
-NumericVector vectorDivide(NumericMatrix x, int rowIndex, double value) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = x(rowIndex, i) / value;
-	}
-	return result;
-}
-
-//double vectorSum(NumericMatrix x, int rowIndex) {
-//	double s = 0;
-//	for (int i = 0; i < x.ncol(); i++) {
-//		s += x(rowIndex, i);
-//	}
-//	return s;
-//}
-
-NumericVector vectorDivide(NumericVector x, NumericVector y) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		if (y[i] != 0.0) {
-			result[i] = x[i] / y[i];
-		}
-	}
-	return result;
-}
-
-NumericVector vectorMultiply(NumericVector x, double multiplier) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = x[i] * multiplier;
-	}
-	return result;
-}
-
-NumericVector vectorMultiply(NumericVector x, NumericVector y) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = x[i] * y[i];
-	}
-	return result;
-}
-
-NumericVector vectorPow(NumericVector x, NumericVector y) {
-	int n = x.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = pow(x[i], y[i]);
-	}
-	return result;
-}
-
-NumericVector vectorPow(double x, NumericVector y) {
-	int n = y.size();
-	NumericVector result = NumericVector(n, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		result[i] = pow(x, y[i]);
-	}
-	return result;
-}
-
-NumericVector vectorRepEachValue(NumericVector x, int kMax) {
-	int n = x.size();
-	NumericVector result = NumericVector(n * kMax, NA_REAL);
-	for (int i = 0; i < n; i++) {
-		for (int j = 0; j < kMax; j++) {
-			result[i * kMax + j] = x[i];
-		}
-	}
-	return result;
-}
-
-double vectorProduct(NumericVector x) {
-	int n = x.size();
-	if (n == 0) {
-		return 0;
-	}
-
-	if (n == 1) {
-		return x[0];
-	}
-
-	double s = x[0];
-	for (int i = 1; i < n; i++) {
-		s *= x[i];
-	}
-	return s;
-}
-
-double vectorProduct(NumericVector x, NumericVector y) {
-	int n = x.size();
-	double s = 0;
-	for (int i = 0; i < n; i++) {
-		s += x[i] * y[i];
-	}
-	return s;
-}
-
-double round(double value, int digits) {
-	double mult = std::pow(10.0, (double)digits);
-	return round(value * mult) / mult;
-}
-
 double findObservationTime(
 		NumericVector accrualTime,
 		NumericVector survivalTime,
@@ -431,8 +302,8 @@ NumericVector getRecalculatedEventSizes(int designNumber, int stage, int kMax,
 		NumericVector criticalValues, NumericVector informationRates,
 		double conditionalPower, NumericVector plannedEvents,
 		double thetaH1, NumericVector eventsPerStage, NumericVector logRankOverStages,
-		NumericVector testStatisticOverStages, NumericVector minNumberOfAdditionalEventsPerStage,
-		NumericVector maxNumberOfAdditionalEventsPerStage,
+		NumericVector testStatisticOverStages, NumericVector minNumberOfEventsPerStage,
+		NumericVector maxNumberOfEventsPerStage,
 		bool directionUpper, double allocation1, double allocation2) {
 
 	double requiredStageEvents = plannedEvents[stage - 1];
@@ -487,8 +358,8 @@ NumericVector getRecalculatedEventSizes(int designNumber, int stage, int kMax,
 			pow(log(theta), 2);
 
 		requiredStageEvents = min(NumericVector::create(
-			max(NumericVector::create(minNumberOfAdditionalEventsPerStage[stage - 1], requiredStageEvents)),
-			maxNumberOfAdditionalEventsPerStage[stage - 1])) + eventsPerStage[stage - 2];
+			max(NumericVector::create(minNumberOfEventsPerStage[stage - 1], requiredStageEvents)),
+			maxNumberOfEventsPerStage[stage - 1])) + eventsPerStage[stage - 2];
 	}
 
 	NumericVector result = NumericVector(3, NA_REAL);
@@ -507,8 +378,8 @@ NumericMatrix getSimulationStepResultsSurvival(
 		double conditionalPower,
 		NumericVector plannedEvents,
 		double thetaH1,
-		NumericVector minNumberOfAdditionalEventsPerStage,
-		NumericVector maxNumberOfAdditionalEventsPerStage,
+		NumericVector minNumberOfEventsPerStage,
+		NumericVector maxNumberOfEventsPerStage,
 		bool directionUpper,
 		double allocation1,
 		double allocation2,
@@ -532,6 +403,7 @@ NumericMatrix getSimulationStepResultsSurvival(
 	NumericVector rejections = NumericVector(kMax, 0.0);
 	NumericVector eventsNotAchieved = NumericVector(kMax, 0.0);
 	NumericVector futilityStops = NumericVector(kMax, 0.0);
+	NumericVector pValuesSeparate = NumericVector(kMax, NA_REAL);
 	NumericVector duration = NumericVector(kMax, 0.0);
 	NumericVector iterations = NumericVector(kMax, 0.0);
 
@@ -548,7 +420,7 @@ NumericMatrix getSimulationStepResultsSurvival(
 				designNumber, k, kMax, criticalValues, informationRates,
 				conditionalPower, plannedEvents,
 				thetaH1, eventsPerStage, logRankOverStages, testStatisticOverStages,
-				minNumberOfAdditionalEventsPerStage, maxNumberOfAdditionalEventsPerStage,
+				minNumberOfEventsPerStage, maxNumberOfEventsPerStage,
 				directionUpper, allocation1, allocation2);
 
 		double requiredStageEvents = recalculatedEventSizes[0];
@@ -597,6 +469,7 @@ NumericMatrix getSimulationStepResultsSurvival(
 
 		int trialStopEventCounter = 0;
 		if (designNumber == 3) { // Fisher design
+			pValuesSeparate[k - 1] = testStatistic[1];
 			if (testStatistic[0] <= criticalValues[k - 1]) {
 				rejections[k - 1]++;
 				trialStopEventCounter++;
@@ -632,7 +505,13 @@ NumericMatrix getSimulationStepResultsSurvival(
 
 		expectedNumberOfEvents1[k - 1] += events1;
 		expectedNumberOfEvents2[k - 1] += events2;
-		expectedNumberOfEvents[k - 1] += events1 + events2;
+
+		double x = events1 + events2;
+		if (k > 1) {
+		  x -= eventsPerStage[k - 2];
+		}
+		expectedNumberOfEvents[k - 1] += x;
+
 		analysisTime[k - 1] += observationTime;
 		iterations[k - 1]++;
 
@@ -641,7 +520,7 @@ NumericMatrix getSimulationStepResultsSurvival(
 		}
 	}
 
-	NumericMatrix result(kMax, 17);
+	NumericMatrix result(kMax, 18);
 	result(_, 0) = analysisTime;
 	result(_, 1) = subjects;
 	result(_, 2) = expectedNumberOfEvents1;
@@ -659,11 +538,12 @@ NumericMatrix getSimulationStepResultsSurvival(
 	result(_, 14) = hazardRatiosEstimate;
 	result(_, 15) = observationTimePerStage;
 	result(_, 16) = conditionalPowerAchieved;
+	result(_, 17) = pValuesSeparate;
 	return result;
 }
 
 /**
- * Weibull:     (-log(1 - runif(0.0, 1.0)))^(1 / kappa) / rate
+ * Weibull: (-log(1 - runif(0.0, 1.0)))^(1 / kappa) / rate
  */
 // [[Rcpp::export]]
 double getRandomSurvivalDistribution(double rate, double kappa) {
@@ -744,10 +624,8 @@ NumericMatrix getExtendedSurvivalDataSet(IntegerVector treatmentGroup,
 	NumericVector dropoutTime = NumericVector(maxNumberOfSubjects, NA_REAL);
 
 	for (int i = 0; i < maxNumberOfSubjects; i++) {
-
 		if (treatmentGroup[i] == 1) {
-			survivalTime[i] = getRandomPiecewiseExponentialDistribution(
-					cdfValues1, lambdaVec1, piecewiseSurvivalTime);
+			survivalTime[i] = getRandomPiecewiseExponentialDistribution(cdfValues1, lambdaVec1, piecewiseSurvivalTime);
 			if (phi1 > 0) {
 				dropoutTime[i] = getRandomPiecewiseExponentialDistribution(
 						cdfValues1, rep(phi1, lambdaVec1.size()), piecewiseSurvivalTime);
@@ -770,20 +648,20 @@ NumericMatrix getExtendedSurvivalDataSet(IntegerVector treatmentGroup,
 void assertArgumentsAreValid(
 		int kMax,
 		NumericVector plannedEvents,
-		NumericVector minNumberOfAdditionalEventsPerStage,
-		NumericVector maxNumberOfAdditionalEventsPerStage
+		NumericVector minNumberOfEventsPerStage,
+		NumericVector maxNumberOfEventsPerStage
 		) {
 
-	if (kMax > minNumberOfAdditionalEventsPerStage.size()) {
+	if (kMax > minNumberOfEventsPerStage.size()) {
 		throw Rcpp::exception(tfm::format(
-			"'minNumberOfAdditionalEventsPerStage' must have length %s (is %s)",
-			kMax, minNumberOfAdditionalEventsPerStage.size()).c_str());
+			"'minNumberOfEventsPerStage' must have length %s (is %s)",
+			kMax, minNumberOfEventsPerStage.size()).c_str());
 	}
 
-	if (kMax > maxNumberOfAdditionalEventsPerStage.size()) {
+	if (kMax > maxNumberOfEventsPerStage.size()) {
 		throw Rcpp::exception(tfm::format(
-			"'maxNumberOfAdditionalEventsPerStage' must have length %s (is %s)",
-			kMax, maxNumberOfAdditionalEventsPerStage.size()).c_str());
+			"'maxNumberOfEventsPerStage' must have length %s (is %s)",
+			kMax, maxNumberOfEventsPerStage.size()).c_str());
 	}
 
 	if (kMax > plannedEvents.size()) {
@@ -793,34 +671,15 @@ void assertArgumentsAreValid(
 	}
 }
 
-void vectorSumC(int i, int j, int kMax, double* x, NumericMatrix y) {
-	for (int k = 0; k < kMax; k++) {
-    	x[i * kMax + k] += y(k, j);
-    }
-}
-
-void vectorInitC(int i, int kMax, double* x, double value) {
-    for (int k = 0; k < kMax; k++) {
-    	x[i * kMax + k] = value;
-    }
-}
-
-void logDebug(std::string s) {
-	Rcout << s << std::endl;
-}
-
 bool isPiecewiseExponentialSurvivalEnabled(NumericVector lambdaVec2) {
-
-	if (lambdaVec2.size() == 0) {
+	if (lambdaVec2.size() <= 1) {
 		return false;
 	}
-
 	for (int i = 0; i < lambdaVec2.size(); i++) {
 		if (R_IsNA(lambdaVec2[i])) {
 			return false;
 		}
 	}
-
 	return true;
 }
 
@@ -853,8 +712,8 @@ List getSimulationSurvivalCpp(
 		double conditionalPower,
 		NumericVector plannedEvents,
 		double thetaH1,
-		NumericVector minNumberOfAdditionalEventsPerStage,
-		NumericVector maxNumberOfAdditionalEventsPerStage,
+		NumericVector minNumberOfEventsPerStage,
+		NumericVector maxNumberOfEventsPerStage,
 		bool directionUpper,
 		double allocation1,
 		double allocation2,
@@ -918,6 +777,7 @@ List getSimulationSurvivalCpp(
 	NumericVector rejections = NumericVector(simResultsVectorLength, NA_REAL);
 	NumericVector eventsNotAchieved = NumericVector(simResultsVectorLength, NA_REAL);
 	NumericVector futilityStops = NumericVector(simResultsVectorLength, NA_REAL);
+	NumericVector pValuesSeparate = NumericVector(simResultsVectorLength, NA_REAL);
 	NumericVector testStatistics = NumericVector(simResultsVectorLength, NA_REAL);
 	NumericVector logRankStatistics = NumericVector(simResultsVectorLength, NA_REAL);
 	NumericVector hazardRates1 = NumericVector(simResultsVectorLength, NA_REAL);
@@ -954,10 +814,16 @@ List getSimulationSurvivalCpp(
 		double hazardRatio = NA_REAL;
 		double lambda1 = NA_REAL;
 		double lambda2 = NA_REAL;
+
 		if (!pwExpEnabled) {
-			pi1 = pi1Vec[pi1Index];
-			lambda1 = getLambdaByPi(pi1, eventTime, kappa);
-			lambda2 = getLambdaByPi(pi2, eventTime, kappa);
+			if (R_IsNA(pi1Vec[pi1Index])) {
+				lambda1 = lambdaVec1[pi1Index];
+				lambda2 = lambdaVec2[0];
+			} else {
+				pi1 = pi1Vec[pi1Index];
+				lambda1 = getLambdaByPi(pi1, eventTime, kappa);
+				lambda2 = getLambdaByPi(pi2, eventTime, kappa);
+			}
 			hazardRatio = pow(lambda1 / lambda2, kappa);
 		}
 
@@ -991,8 +857,8 @@ List getSimulationSurvivalCpp(
 				conditionalPower,
 				plannedEvents,
 				thetaH1,
-				minNumberOfAdditionalEventsPerStage,
-				maxNumberOfAdditionalEventsPerStage,
+				minNumberOfEventsPerStage,
+				maxNumberOfEventsPerStage,
 				directionUpper,
 				allocation1,
 				allocation2,
@@ -1013,6 +879,7 @@ List getSimulationSurvivalCpp(
 			vectorSumC(pi1Index, 8, kMax, REAL(durationsSum), stepResults);
 			vectorSumC(pi1Index, 9, kMax, REAL(iterationsSum), stepResults);
 			vectorSumC(pi1Index, 16, kMax, REAL(conditionalPowerAchievedSum), stepResults); // conditionalPowerAchieved
+			// pValuesSeparate
 
 			// get data
 			for (int k = 0; k < kMax; k++) {
@@ -1038,6 +905,7 @@ List getSimulationSurvivalCpp(
 					hazardRatiosEstimate[index] = stepResults(k, 14);
 
 					conditionalPowerAchieved[index] = stepResults(k, 16);
+					pValuesSeparate[index] = stepResults(k, 17);
 
 					index++;
 				}
@@ -1143,15 +1011,16 @@ List getSimulationSurvivalCpp(
 		Named("hazardRatio") = hazardRatios,
 		Named("analysisTime") = analysisTime,
 		Named("numberOfSubjects") = subjects,
-		Named("eventsPerStage1") = events1,
-		Named("eventsPerStage2") = events2,
+		Named("overallEvents1") = events1,
+		Named("overallEvents2") = events2,
 		Named("eventsPerStage") = events,
 		Named("rejectPerStage") = rejections,
 		Named("eventsNotAchieved") = eventsNotAchieved,
 		Named("futilityPerStage") = futilityStops,
 		Named("testStatistic") = testStatistics,
 		Named("logRankStatistic") = logRankStatistics,
-		Named("conditionalPowerAchieved") = conditionalPowerAchieved
+		Named("conditionalPowerAchieved") = conditionalPowerAchieved,
+		Named("pValuesSeparate") = pValuesSeparate
 	);
 
 	if (maxNumberOfRawDatasetsPerStage > 0) {
